# Python toolbox for Heart Rate Variability and Stress Level Analysis.
## Getting Started

### Installation
This toolbox can be installed using the ```pip``` package manager.
```
pip install rmlhrv
```

### Dependencies
- numpy
- scipy
- matplotlib
- nolds

### Disclaimer
This program is distributed in the hope it will be useful and provided to you "as is", but WITHOUT ANY WARRANTY, without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. This program is NOT intended for medical diagnosis. We expressly disclaim any liability whatsoever for any direct, indirect, consequential, incidental or special damages, including, without limitation, lost revenues, lost profits, losses resulting from business interruption or loss of data, regardless of the form of action or legal theory under which the liability may be asserted, even if advised of the possibility of such damages.
